summaryrefslogtreecommitdiff
path: root/board
diff options
context:
space:
mode:
authorTom Rini <[email protected]>2025-09-23 08:24:59 -0600
committerTom Rini <[email protected]>2025-09-23 08:24:59 -0600
commitb82a1fa7ddc7f3be2f3b75898d5dc44c34420bdd (patch)
tree6f9b7dceb47e46af0d1a40916eb8a66564ebd2c4 /board
parentd81c1118580f3481b864b830fe5b789519993bd3 (diff)
parent2f2ab7e13a69367cc9b88a45899e24dba02667c6 (diff)
Merge tag 'v2025.10-rc5' into next
Prepare v2025.10-rc5
Diffstat (limited to 'board')
-rw-r--r--board/dhelectronics/dh_stm32mp1/board.c6
-rw-r--r--board/freescale/imx8ulp_evk/spl.c4
-rw-r--r--board/freescale/imx95_evk/MAINTAINERS1
-rw-r--r--board/phytec/phycore_imx93/spl.c37
-rw-r--r--board/starfive/visionfive2/spl.c16
-rw-r--r--board/starfive/visionfive2/starfive_visionfive2.c18
-rw-r--r--board/ti/am57xx/am57xx.env2
7 files changed, 33 insertions, 51 deletions
diff --git a/board/dhelectronics/dh_stm32mp1/board.c b/board/dhelectronics/dh_stm32mp1/board.c
index f7347bbb826..bd9326d6b1b 100644
--- a/board/dhelectronics/dh_stm32mp1/board.c
+++ b/board/dhelectronics/dh_stm32mp1/board.c
@@ -85,6 +85,9 @@ static bool dh_stm32_mac_is_in_ks8851(void)
if (!ofnode_valid(node))
return false;
+ if (!ofnode_device_is_compatible(node, "micrel,ks8851-mll"))
+ return false;
+
ret = ofnode_get_path(node, path, sizeof(path));
if (ret)
return false;
@@ -93,9 +96,6 @@ static bool dh_stm32_mac_is_in_ks8851(void)
if (ret)
return false;
- if (!ofnode_device_is_compatible(node, "micrel,ks8851-mll"))
- return false;
-
/*
* KS8851 with EEPROM may use custom MAC from EEPROM, read
* out the KS8851 CCR register to determine whether EEPROM
diff --git a/board/freescale/imx8ulp_evk/spl.c b/board/freescale/imx8ulp_evk/spl.c
index d123b21b722..fe637077928 100644
--- a/board/freescale/imx8ulp_evk/spl.c
+++ b/board/freescale/imx8ulp_evk/spl.c
@@ -69,8 +69,8 @@ void display_ele_fw_version(void)
} else {
printf("ELE firmware version %u.%u.%u-%x",
(fw_version & (0x00ff0000)) >> 16,
- (fw_version & (0x0000ff00)) >> 8,
- (fw_version & (0x000000ff)), sha1);
+ (fw_version & (0x0000fff0)) >> 4,
+ (fw_version & (0x0000000f)), sha1);
((fw_version & (0x80000000)) >> 31) == 1 ? puts("-dirty\n") : puts("\n");
}
}
diff --git a/board/freescale/imx95_evk/MAINTAINERS b/board/freescale/imx95_evk/MAINTAINERS
index 5caf763e0cc..9d5c4e41b65 100644
--- a/board/freescale/imx95_evk/MAINTAINERS
+++ b/board/freescale/imx95_evk/MAINTAINERS
@@ -3,4 +3,5 @@ M: Alice Guo <[email protected]>
S: Maintained
F: board/freescale/imx95_evk/
F: include/configs/imx95_evk.h
+F: configs/imx95_a0_19x19_evk_defconfig
F: configs/imx95_19x19_evk_defconfig
diff --git a/board/starfive/visionfive2/spl.c b/board/starfive/visionfive2/spl.c
index fe14b44ce28..420a8cf8d91 100644
--- a/board/starfive/visionfive2/spl.c
+++ b/board/starfive/visionfive2/spl.c
@@ -127,19 +127,11 @@ int board_fit_config_name_match(const char *name)
!strncmp(get_product_id_from_eeprom(), "STAR64", 6)) {
return 0;
} else if (!strcmp(name, "starfive/jh7110-starfive-visionfive-2-v1.2a") &&
- !strncmp(get_product_id_from_eeprom(), "VF7110", 6)) {
- switch (get_pcb_revision_from_eeprom()) {
- case 'a':
- case 'A':
- return 0;
- }
+ !strncmp(get_product_id_from_eeprom(), "VF7110A", 7)) {
+ return 0;
} else if (!strcmp(name, "starfive/jh7110-starfive-visionfive-2-v1.3b") &&
- !strncmp(get_product_id_from_eeprom(), "VF7110", 6)) {
- switch (get_pcb_revision_from_eeprom()) {
- case 'b':
- case 'B':
- return 0;
- }
+ !strncmp(get_product_id_from_eeprom(), "VF7110B", 7)) {
+ return 0;
}
return -EINVAL;
diff --git a/board/starfive/visionfive2/starfive_visionfive2.c b/board/starfive/visionfive2/starfive_visionfive2.c
index bfbb11a2ee7..6271974b9c7 100644
--- a/board/starfive/visionfive2/starfive_visionfive2.c
+++ b/board/starfive/visionfive2/starfive_visionfive2.c
@@ -59,20 +59,10 @@ static void set_fdtfile(void)
fdtfile = "starfive/jh7110-milkv-mars.dtb";
} else if (!strncmp(get_product_id_from_eeprom(), "STAR64", 6)) {
fdtfile = "starfive/jh7110-pine64-star64.dtb";
- } else if (!strncmp(get_product_id_from_eeprom(), "VF7110", 6)) {
- switch (get_pcb_revision_from_eeprom()) {
- case 'a':
- case 'A':
- fdtfile = "starfive/jh7110-starfive-visionfive-2-v1.2a.dtb";
- break;
- case 'b':
- case 'B':
- fdtfile = "starfive/jh7110-starfive-visionfive-2-v1.3b.dtb";
- break;
- default:
- log_err("Unknown revision\n");
- return;
- }
+ } else if (!strncmp(get_product_id_from_eeprom(), "VF7110A", 7)) {
+ fdtfile = "starfive/jh7110-starfive-visionfive-2-v1.2a.dtb";
+ } else if (!strncmp(get_product_id_from_eeprom(), "VF7110B", 7)) {
+ fdtfile = "starfive/jh7110-starfive-visionfive-2-v1.3b.dtb";
} else {
log_err("Unknown product\n");
return;
diff --git a/board/ti/am57xx/am57xx.env b/board/ti/am57xx/am57xx.env
index 7d029a3e859..a7cbbced099 100644
--- a/board/ti/am57xx/am57xx.env
+++ b/board/ti/am57xx/am57xx.env
@@ -10,7 +10,7 @@ get_name_kern=
else
setenv bootfile zImage;
fi
-get_fit_config=setenv name_fit_config ${fdtfile}
+get_fit_config=setexpr name_fit_config gsub "ti/omap/" "" ${fdtfile}
console=ttyS2,115200n8
fdtfile=undefined
finduuid=part uuid mmc 0:2 uuid
diff --git a/board/phytec/phycore_imx93/spl.c b/board/phytec/phycore_imx93/spl.c
index 7feee4bcf6f..aa7d562911a 100644
--- a/board/phytec/phycore_imx93/spl.c
+++ b/board/phytec/phycore_imx93/spl.c
@@ -93,7 +93,7 @@ int power_init_board(void)
{
struct udevice *dev;
int ret;
- unsigned int val = 0;
+ unsigned int val = 0, buck_val;
ret = pmic_get("pmic@25", &dev);
if (ret == -ENODEV) {
@@ -115,24 +115,23 @@ int power_init_board(void)
return ret;
val = ret;
- if (IS_ENABLED(CONFIG_IMX9_LOW_DRIVE_MODE)) {
- /* 0.8v for Low drive mode */
- if (val & PCA9450_REG_PWRCTRL_TOFF_DEB) {
- pmic_reg_write(dev, PCA9450_BUCK1OUT_DVS0, 0x0c);
- pmic_reg_write(dev, PCA9450_BUCK3OUT_DVS0, 0x0c);
- } else {
- pmic_reg_write(dev, PCA9450_BUCK1OUT_DVS0, 0x10);
- pmic_reg_write(dev, PCA9450_BUCK3OUT_DVS0, 0x10);
- }
+ if (is_voltage_mode(VOLT_LOW_DRIVE)) {
+ buck_val = 0x0c; /* 0.8v for Low drive mode */
+ printf("PMIC: Low Drive Voltage Mode\n");
+ } else if (is_voltage_mode(VOLT_NOMINAL_DRIVE)) {
+ buck_val = 0x10; /* 0.85v for Nominal drive mode */
+ printf("PMIC: Nominal Voltage Mode\n");
} else {
- /* 0.9v for Over drive mode */
- if (val & PCA9450_REG_PWRCTRL_TOFF_DEB) {
- pmic_reg_write(dev, PCA9450_BUCK1OUT_DVS0, 0x14);
- pmic_reg_write(dev, PCA9450_BUCK3OUT_DVS0, 0x14);
- } else {
- pmic_reg_write(dev, PCA9450_BUCK1OUT_DVS0, 0x18);
- pmic_reg_write(dev, PCA9450_BUCK3OUT_DVS0, 0x18);
- }
+ buck_val = 0x14; /* 0.9v for Over drive mode */
+ printf("PMIC: Over Drive Voltage Mode\n");
+ }
+
+ if (val & PCA9450_REG_PWRCTRL_TOFF_DEB) {
+ pmic_reg_write(dev, PCA9450_BUCK1OUT_DVS0, buck_val);
+ pmic_reg_write(dev, PCA9450_BUCK3OUT_DVS0, buck_val);
+ } else {
+ pmic_reg_write(dev, PCA9450_BUCK1OUT_DVS0, buck_val + 0x4);
+ pmic_reg_write(dev, PCA9450_BUCK3OUT_DVS0, buck_val + 0x4);
}
/* set standby voltage to 0.65v */
@@ -174,7 +173,7 @@ void board_init_f(ulong dummy)
power_init_board();
- if (!IS_ENABLED(CONFIG_IMX9_LOW_DRIVE_MODE))
+ if (!is_voltage_mode(VOLT_LOW_DRIVE))
set_arm_core_max_clk();
/* Init power of mix */